smartcard.reader.ReaderFactory.ReaderFactory

# ``smartcard`.`reader`.`ReaderFactory`.`ReaderFactory``

class documentation

`class ReaderFactory(object):`

View In Hierarchy

Class to create readers from reader type id.

Static Method | `createReader` | Static method to create a reader from a reader clazz.
Static Method | `readers` | Undocumented
Class Variable | `factories` | Undocumented
Class Variable | `factorymethods` | Undocumented

def createReader(clazz, readername):

Static method to create a reader from a reader clazz.

Parameters
clazz | the reader class name
readername | the reader name

def readers(groups=[]):

Undocumented

factories: `dict` =

Undocumented

factorymethods =

Undocumented